@@ -1,6 +1,6 @@
 #' @title Shiny app: inventory of htsr sqlite data base
 #'
-#' @author P. Chevallier - Sep-Nov 2020
+#' @author P. Chevallier - Sep 2020 - Aug 2023
 #'
 #' @description Shiny application of the \code{\link{d_inventory}} function
 #'
@@ -13,14 +13,11 @@
 #' @details If the data do not exist, the app crashes and error messages
 #' are displayed in the console window.
 #'
-#' @param fsq File name of the Sqlite data base
 
 #' @return a shiny session
 #'
 #'
-ds_inventory <- function(fsq){
-  fsq <- fsq
-  save(fsq, file=system.file("extdata/fichier_fsq.RData",package="htsr"))
-  #unApp(system.file("extdata/app_invent", package="htsr"),launch.browser=TRUE)
+ds_inventory <- function(){
+  #runApp(system.file("extdata/app_invent", package="htsr"),launch.browser=TRUE)
   runApp(system.file("extdata/app_invent", package="htsr"))
 }
