@@ -1,6 +1,6 @@
 #' @title Shiny app: create, modify or remove a sensor from a data base
 #'
-#' @author P. Chevallier - Nov 2020
+#' @author P. Chevallier - Nov 2020 - Aug 2023
 #'
 #' @description Shiny application of the \code{\link{d_sensor}} function
 #'
@@ -9,8 +9,5 @@
 #' @return a shiny session
 #'
 ds_sensor <- function(fsq) {
-  fsq <- fsq
-  save(fsq, file=system.file("extdata/fichier_fsq.RData",package="htsr"))
-  #runApp(system.file("extdata/app_sensor", package="htsr"),launch.browser=TRUE)
   runApp(system.file("extdata/app_sensor", package="htsr"))
 }
